*	File: hazard rate
* 	Purpose: Creates empirical hazard rate
*
*===============================================================================
cd "~/Dropbox (Personal)/engelhardt-rupert/begr/stata/data"
clear all
set maxvar 15000
*-------------------------------------------------------------------------------
*	Standard Data set
*-------------------------------------------------------------------------------
* read in data
insheet using NLSYdataU_bryan.csv, comma names clear

* sort by person and duration
gen temp = _n
sort id temp

* create spell id 
by id: gen spell_id = _n

* find number of spells per person
drop temp
gen temp = length>0
by id: egen num_dur = total(temp)

* keep only first and second spell
keep if num_dur>1
keep if length>0
sort id age

* create new spell id
by id: gen spell_id2 = _n
rename length duration

* save data
save U_fullsample,replace

*------------- Create sample of two spell periods ------------*
use U_fullsample,clear
// spells 1 and 2
keep if e
keep if spell_id2 <3

* repshape to wide
keep duration id spell_id2
reshape wide duration, i(id) j(spell_id2)

* save 
save U_twospells,replace

// rest of the two spell sets
forvalues k=2/9{
use U_fullsample,clear
keep if e
keep if num_dur>=`k'+1
keep if spell_id2 == `k' | spell_id2 == `k'+1
replace spell_id2 = spell_id2-(`k'-1)

* repshape to wide
keep duration id spell_id2
reshape wide duration, i(id) j(spell_id2)

append using U_twospells
save U_twospells,replace
}

*------------- Continue making hazard  ------------*
* count spells
gen N_tot = 0

forvalues k = 1/52{
forvalues j = 1/52{

* drop temp variable
capture drop temp

* create temp variable
if `k' <52{
if `j' < 52{
gen temp = (duration1==`k')&(duration2==`j')
replace temp = 1 if (duration1==`j')&(duration2==`k')
}
else{
gen temp = (duration1==`k')&(duration2>=`j')
replace temp = 1 if (duration1>=`j')&(duration2==`k')
}
}
else{
if `j' < 52{
gen temp = (duration1>=`k')&(duration2==`j')
replace temp = 1 if (duration1==`j')&(duration2>=`k')
}
else{
gen temp = (duration1>=`k')&(duration2>=`j')
replace temp = 1 if (duration1>=`j')&(duration2>=`k')
}
}
* create count variable
egen n_k`k'j`j' = total(temp)
replace n_k`k'j`j'  = n_k`k'j`j'/2

* add to running total
replace N_tot = N_tot + n_k`k'j`j'
}
}

* reshape to long and rename 
keep if _n==1
reshape long n_, i(id) j(N) string

split N, p("j")
destring N2,replace

split N1, p("k")
destring N12, replace

drop N N1 N11 duration1 duration2 temp id
rename N12 N1

* create survival function 
gsort +N1 -N2
by N1: gen cumsum = sum(n_)

gsort +N2 -N1
by N2: gen fsum = sum(cumsum)

sort N1 N2

gen survival = fsum/N_tot

by N1: gen hazard = (survival[_n] - survival[_n+1])/((N2[_n+1]-N2[_n])*survival[_n])

* save
save hazard_U,replace

* create t1 groups
gen group = 1 if N1 <= 10
replace group = 2 if N1>10 & N1<=20
replace group = 3 if N1>20 & N1<=30

* create groups for t2
gen group2 = 2.5 if N2 <5
replace group2 = 7.5 if N2>=5 & N2<10
replace group2 = 12.5 if N2>=10 & N2<15
replace group2 = 17.5 if N2>=15 & N2<20
replace group2 = 22.5 if N2>=20 & N2<25
replace group2 = 27.5 if N2>=25 & N2<30
replace group2 = 32.5 if N2>=30 & N2<35
replace group2 = 37.5 if N2>=35 & N2<40
replace group2 = 46 if N2>=40 

* collapse 
gen sd = hazard
collapse (mean) hazard (sd) sd, by(group group2)
outsheet using hazard_tot_U.csv, comma names replace

*-------------------------------------------------------------------------------
*	Inclusive Data set
*-------------------------------------------------------------------------------
* read in data
insheet using NLSYdataN_bryan.csv, comma names clear

* sort by person and duration
gen temp = _n
sort id temp

* create spell id 
by id: gen spell_id = _n

* find number of spells per person
drop temp
gen temp = length>0
by id: egen num_dur = total(temp)

* keep only first and second spell
keep if num_dur>1
keep if length>0
sort id spell_id

* create new spell id
by id: gen spell_id2 = _n
rename length duration

* save data
save N_fullsample,replace

*------------- Create sample of two spell periods ------------*

// spells 1 and 2
keep if e
keep if spell_id2 <3

* repshape to wide
keep duration id spell_id2
reshape wide duration, i(id) j(spell_id2)

* save 
save N_twospells,replace

// rest of the two spell sets
forvalues k=2/9{
use N_fullsample,clear
keep if e
keep if num_dur>=`k'+1
keep if spell_id2 == `k' | spell_id2 == `k'+1
replace spell_id2 = spell_id2-(`k'-1)

* repshape to wide
keep duration id spell_id2
reshape wide duration, i(id) j(spell_id2)

append using N_twospells
save N_twospells,replace
}

*------------- Continue making hazard  ------------*
* count spells
gen N_tot = 0


forvalues k = 1/104{
forvalues j = 1/104{

* drop temp variable
capture drop temp

* create temp variable
if `k' <104{
if `j' < 104{
gen temp = (duration1==`k')&(duration2==`j')
replace temp = 1 if (duration1==`j')&(duration2==`k')
}
else{
gen temp = (duration1==`k')&(duration2>=`j')
replace temp = 1 if (duration1>=`j')&(duration2==`k')
}
}
else{
if `j' < 104{
gen temp = (duration1>=`k')&(duration2==`j')
replace temp = 1 if (duration1==`j')&(duration2>=`k')
}
else{
gen temp = (duration1>=`k')&(duration2>=`j')
replace temp = 1 if (duration1>=`j')&(duration2>=`k')
}
}
* create count variable
egen n_k`k'j`j' = total(temp)
replace n_k`k'j`j'  = n_k`k'j`j'/2

* add to running total
replace N_tot = N_tot + n_k`k'j`j'
}
}

* reshape to long and rename 
keep if _n==1
reshape long n_, i(id) j(N) string

split N, p("j")
destring N2,replace

split N1, p("k")
destring N12, replace

drop N N1 N11 duration1 duration2 temp id
rename N12 N1

* create survival function 
gsort +N1 -N2
by N1: gen cumsum = sum(n_)

gsort +N2 -N1
by N2: gen fsum = sum(cumsum)

sort N1 N2

gen survival = fsum/N_tot

by N1: gen hazard = (survival[_n] - survival[_n+1])/((N2[_n+1]-N2[_n])*survival[_n])

* save
save hazard_N,replace

* create t1 groups
gen group = 1 if N1 <= 20
replace group = 2 if N1>20 & N1<=40
replace group = 3 if N1>40 & N1<=60

* create groups for t2
gen group2 = 2.5 if N2 <5
replace group2 = 7.5 if N2>=5 & N2<10
replace group2 = 12.5 if N2>=10 & N2<15
replace group2 = 17.5 if N2>=15 & N2<20
replace group2 = 22.5 if N2>=20 & N2<25
replace group2 = 27.5 if N2>=25 & N2<30
replace group2 = 32.5 if N2>=30 & N2<35
replace group2 = 37.5 if N2>=35 & N2<40
replace group2 = 42.5 if N2>=40 & N2<45
replace group2 = 47.5 if N2>=45 & N2<50
replace group2 = 52.5 if N2>=50 & N2<55
replace group2 = 57.5 if N2>=55 & N2<60
replace group2 = 62.5 if N2>=60 & N2<65
replace group2 = 67.5 if N2>=65 & N2<70
replace group2 = 72.5 if N2>=70 & N2<75
replace group2 = 77.5 if N2>=75 & N2<80
replace group2 = 82.5 if N2>=80 & N2<85
replace group2 = 87.5 if N2>=85 & N2<90
replace group2 = 92.5 if N2>=90 & N2<95
replace group2 = 97.5 if N2>=95 & N2<100
replace group2 = 102 if N2>=100 

* collapse 
gen sd = hazard
collapse (mean) hazard (sd) sd, by(group group2)
outsheet using hazard_tot_N.csv, comma names replace
