#   File: hazard_plots.R
#
#	Notes:
#===================================================================================================
rm(list=ls())
library(quantmod)
library(PerformanceAnalytics)
library(mFilter)
library(seasonal)
library(ggplot2)
Sys.setenv(TZ='GMT')

setwd("~/Dropbox (Personal)/engelhardt-rupert/begr/stata/data")

colors <- c("deepskyblue4","brown3","darkolivegreen4","cornflowerblue","darkorange3","brown4","mediumpurple4")

outputLocation <- '~/Dropbox (Personal)/engelhardt-rupert/begr/stata/graphs/'

#-----------------------------------------------------------
#	Data
#-----------------------------------------------------------

hazardU <- read.csv('hazard_tot_U.csv', stringsAsFactors=F, header = T)
hazardU <- hazardU[!is.na(hazardU$group),]
hazardU1 <- read.csv('hazard_w1_U.csv', stringsAsFactors=F, header = T)
hazardU1 <- hazardU1[!is.na(hazardU1$group),]
hazardU2 <- read.csv('hazard_w2_U.csv', stringsAsFactors=F, header = T)
hazardU2 <- hazardU2[!is.na(hazardU2$group),]
hazardU3 <- read.csv('hazard_w3_U.csv', stringsAsFactors=F, header = T)
hazardU3 <- hazardU3[!is.na(hazardU3$group),]

hazardN <- read.csv('hazard_tot_N.csv', stringsAsFactors=F, header = T)
hazardN <- hazardN[!is.na(hazardN$group),]
hazardN1 <- read.csv('hazard_w1_N.csv', stringsAsFactors=F, header = T)
hazardN1 <- hazardN1[!is.na(hazardN1$group),]
hazardN2 <- read.csv('hazard_w2_N.csv', stringsAsFactors=F, header = T)
hazardN2 <- hazardN2[!is.na(hazardN2$group),]
hazardN3 <- read.csv('hazard_w3_N.csv', stringsAsFactors=F, header = T)
hazardN3 <- hazardN3[!is.na(hazardN3$group),]

#-----------------------------------------------------------
#	Graphs
#-----------------------------------------------------------
##### hazard U ######
p = ggplot()+
		geom_line(
			data = hazardU,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-10 weeks','11-20 weeks','21-30 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardU.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard U no recalls ######
p = ggplot()+
		geom_line(
			data = hazardU_NRC,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-10 weeks','11-20 weeks','21-30 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardU_NRC.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()


##### hazard N ######
p = ggplot()+
		geom_line(
			data = hazardN,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-20 weeks','21-40 weeks','41-60 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardN.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard U1 ######
p = ggplot()+
		geom_line(
			data = hazardU1,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-10 weeks','11-20 weeks','21-30 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardU1.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard U2 ######
p = ggplot()+
		geom_line(
			data = hazardU2,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-10 weeks','11-20 weeks','21-30 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardU2.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard U3 ######
p = ggplot()+
		geom_line(
			data = hazardU3,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-10 weeks','11-20 weeks','21-30 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardU3.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard N1 ######
p = ggplot()+
		geom_line(
			data = hazardN1,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-20 weeks','21-40 weeks','41-60 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardN1.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard N2 ######
p = ggplot()+
		geom_line(
			data = hazardN2,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-20 weeks','21-40 weeks','41-60 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardN2.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()

##### hazard N3 ######
p = ggplot()+
		geom_line(
			data = hazardN3,
			aes( x = group2, y = hazard, color = factor(group)),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			labels = c('1-20 weeks','21-40 weeks','41-60 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardN3.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()