#   File: hazard_plots.R
#
#	Notes:
#===================================================================================================
rm(list=ls())
library(quantmod)
library(PerformanceAnalytics)
library(mFilter)
library(seasonal)
library(ggplot2)
Sys.setenv(TZ='GMT')

setwd("~/Dropbox (Personal)/engelhardt-rupert/begr/stata/data")

colors <- c("deepskyblue4","brown3","darkolivegreen4","cornflowerblue","darkorange3","brown4","mediumpurple4")

outputLocation <- '~/Dropbox (Personal)/engelhardt-rupert/begr/stata/graphs/'

#-----------------------------------------------------------
#	Data
#-----------------------------------------------------------
hazardU_NRC <- read.csv('hazard_tot_U_norecall.csv', stringsAsFactors=F, header = T)
hazardU_NRC <- hazardU_NRC[!is.na(hazardU_NRC$group),]
hazardU_NRC$type <- 'No Recall'
hazardU_RC <- read.csv('hazard_tot_U_recall.csv', stringsAsFactors=F, header = T)
hazardU_RC <- hazardU_RC[!is.na(hazardU_RC$group),]
hazardU_RC$type <- 'Recall'

data.plot <- rbind(hazardU_NRC,hazardU_RC)
#-----------------------------------------------------------
#	Graphs
#-----------------------------------------------------------
##### hazard U ######
p = ggplot()+
		geom_line(
			data = data.plot,
			aes( x = group2, y = hazard, color = type),
			stat = 'identity',
			position = 'identity',
			size = 1
			)+
		labs(
			title= '',
			x = 'Weeks Unemployed',
			y = 'Hazard Rate') +
		theme(
			panel.background = element_rect(fill = 'white'), 
			panel.grid.major = element_line(color = 'grey80'), 
			panel.grid.minor = element_line(color = 'grey80'), 
			axis.text = element_text(color = 'black',size = 12), 
			title = element_text(size=12),
			legend.key = element_rect(fill = 'white',size = 2),
			legend.title = element_blank(),
			legend.text=element_text(size=12),
			legend.position = 'bottom') +
		scale_color_manual(
			#labels = c('1-10 weeks','11-20 weeks','21-30 weeks'),
			values = colors, 
			guide = guide_legend())
print(p)

setEPS()
postscript(paste(outputLocation,"hazardU_recall.eps", sep=""), family="Times", pointsize=10, height = 4, width = 6)	
print(p)
dev.off()
graphics.off()
