*	File: summary stats
* 	Purpose: Creates summary stats by UI takers and non takers
*
*===============================================================================
cd "~/Dropbox (Personal)/engelhardt-rupert/begr/stata/data"

*-------------------------------------------------------------------------------
*	Standard Data set
*-------------------------------------------------------------------------------
* read in data
insheet using NLSYdataU_bryan.csv, comma names clear

* sort by person and duration
gen temp = _n
sort id temp

* create spell id 
by id: gen spell_id = _n

* find number of spells per person
drop temp
gen temp = length>0
by id: egen num_dur = total(temp)

* indicator if the person collected any UI 
drop temp
gen temp = ui1+ui2+ui3+ui4+ui5
gen ui_collect = temp>0

* Summary stats by UI takers
eststo ui_U: estpost sum male black hisp edu urban age e if length>0 & ui_collect
eststo noui_U: estpost sum male black hisp edu urban age e if length>0 & !ui_collect

foreach yvar of varlist male black hisp edu urban age e {
    regress `yvar' ui_collect if length>0
}

esttab ui_U noui_U using "~/Dropbox (Personal)/engelhardt-rupert/begr/stata/summaryU_temp.tex", tex label nonumbers mtitle("UI" "No UI" ) collabels("") cells(mean(fmt(%20.2fc))) replace

// test if previous duration differs based on UI uptake on second spell

* keep only first and second spell
keep if num_dur>1
keep if length>0
sort id age
by id: gen spell_id1 = _n

* set time and panel 
xtset id spell_id1

* replace wage=0 with missing if spell did not end with employment and log wage
replace wage = . if !e
gen log_wage = log(wage+0.01)

* regress durations
reg L.length ui_collect, cluster(id)
eststo U_nocov
reg L.length ui_collect male black hisp edu L.urban L.age L.e, cluster(id)
eststo U
xtreg L.length ui_collect L.urban L.age L.e  , fe robust
eststo U_fe

* regression log wage 1 & 2 periods previous
reg L.log_wage ui_collect male black hisp edu L.urban L.age, cluster(id)
eststo Ulnw
xtreg L.log_wage ui_collect L.urban L.age L.ui_collect L.recall, fe robust
eststo Ulnw_fe

reg L2.log_wage ui_collect male black hisp edu L2.urban L2.age, cluster(id)
eststo Ulnw2
xtreg L2.log_wage ui_collect L2.urban L2.age , fe robust
eststo Ulnw2_fe

* make table
esttab U_nocov U U_fe Ulnw_fe Ulnw2_fe using "~/Dropbox (Personal)/engelhardt-rupert/begr/stata/U_unobservable.tex",tex se nonumber label star(* 0.1 ** 0.05 *** 0.01) mtitle("(1)" "(2)" "(3)" "(4)" "(5)") replace

*-------------------------------------------------------------------------------
*	Inclusive Data set
*-------------------------------------------------------------------------------
* read in data
insheet using NLSYdataN.csv, comma names clear

* sort by person and duration
gen temp = _n
sort id temp

* create spell id 
by id: gen spell_id = _n

* find number of spells per person
drop temp
gen temp = duration>0
by id: egen num_dur = total(temp)

* indicator if the person collected any UI 
drop temp
gen temp = ui1+ui2+ui3+ui4+ui5
gen ui_collect = temp>0

* total search variable
gen search_tot = search1+search2+search3+search4+search5

* Summary stats by UI takers
eststo ui_N: estpost sum male black hisp educ urban age emp search_tot if duration>0 & ui_collect
eststo noui_N: estpost sum male black hisp educ urban age emp search_tot if duration>0 & !ui_collect

foreach yvar of varlist male black hisp educ urban age emp search_tot{
    regress `yvar' ui_collect if duration>0
}

esttab ui_N noui_N using "~/Dropbox (Personal)/engelhardt-rupert/begr/stata/summaryN_temp.tex", tex label nonumbers mtitle("UI" "No UI" ) collabels("") cells(mean(fmt(%20.2fc))) replace

// test if previous duration differs based on UI uptake on second spell

* keep only first and second spell
keep if num_dur>1
keep if duration>0
sort id spell_id
by id: gen spell_id1 = _n

* set time and panel 
xtset id spell_id1

* replace wage=0 with missing if spell did not end with employment and log wage
replace wage = . if !emp
gen log_wage = log(wage+0.01)

* regress druations
reg L.duration ui_collect if L.duration < 52, cluster(id)
eststo N
reg L.duration ui_collect L.search1 male black hisp educ L.urban L.age L.emp if L.duration < 52, cluster(id)
eststo N_cov
xtreg L.duration ui_collect L.search1 L.urban L.age L.emp if L.duration < 52, fe
eststo N_fe

* regress wages
reg L.log_wage ui_collect if L.duration < 52, cluster(id)
eststo Nlnw
reg L.log_wage ui_collect  L.search1 male black hisp educ L.urban L.age if L.duration < 52, cluster(id)
eststo Nlnw_cov
xtreg L.log_wage ui_collect L.search1 L.urban L.age if L.duration < 52, fe robust
eststo Nlnw_fe

xtreg L2.log_wage ui_collect L2.search1 L2.urban L2.age if L2.duration < 52, fe robust
eststo Nlnw2_fe

* make table
esttab N N_cov N_fe Nlnw_fe Nlnw2_fe using "~/Dropbox (Personal)/engelhardt-rupert/begr/stata/N_unobservable.tex",tex se nonumber label star(* 0.1 ** 0.05 *** 0.01) mtitle("(1)" "(2)" "(3)" "(4)" "(5)") replace



